{% extends "getitfixed:templates/layout.jinja2" %}
{% block content %}
<div class="container {{ 'issue-view' if issue else '' }}">

  <ol class="breadcrumb">
    <li><a href="{{request.route_url('c2cgeoform_index')}}">{{_('Issues')}}</a></li>
    <li class="active">{{request.translate(item_name[:80]) if item_name else _('Issue')}}</li>
  </ol>

  {% include 'c2cgeoform:/templates/edit.jinja2' %}

</div>
{% endblock content %}
